@@ -28,13 +28,19 @@
 
 G_BEGIN_DECLS
 
+extern const char *_LAST_DATE_TAG_NAMES[];
+extern const char *_ORIGINAL_DATE_TAG_NAMES[];
+extern const char *_DESCRIPTION_TAG_NAMES[];
+
 gboolean   exiv2_read_metadata_from_file    (GFile           *file,
 					     GFileInfo       *info,
+					     GCancellable    *cancellable,
 					     GError         **error);
 gboolean   exiv2_read_metadata_from_buffer  (void            *buffer,
 					     gsize            buffer_size,
 					     GFileInfo       *info,
 					     GError         **error);
+GFile *    exiv2_get_sidecar                (GFile           *file);
 gboolean   exiv2_read_sidecar               (GFile           *file,
 					     GFileInfo       *info);
 gboolean   exiv2_supports_writes            (const char      *mime_type);
